Module prelude

Module prelude 

Commonly used items for glob import.

Re-exports

pub use crate::Context;
pub use crate::NexError;
pub use crate::Result;

Macros

bail
Return early with an error.
ensure
Return early with an error if a condition is not satisfied.
nexerror
Creates a new NexError from a format string.

Derive Macros

Error
Re-export the derive macro so users can use nexcore_error::Error; Derive Display and std::error::Error for an enum or struct.